@@ -31,7 +31,7 @@ from datahub.metadata.schema_classes import MetadataChangeLogClass
 from pydantic import BaseModel
 
 from datahub_actions.action.action import Action
-from datahub_actions.event.event import EventEnvelope
+from datahub_actions.event.event_envelope import EventEnvelope
 from datahub_actions.event.event_registry import METADATA_CHANGE_LOG_EVENT_V1_TYPE
 from datahub_actions.pipeline.pipeline_context import PipelineContext
 
@@ -176,12 +176,18 @@ class ExecutorAction(Action):
     ) -> ReportingExecutorConfig:
 
         # Build default task config
-        local_task_config = config.task_config or TaskConfig(
+        ingest_task_config = config.task_config or TaskConfig(
             name="RUN_INGEST",
             type="acryl.executor.execution.sub_process_ingestion_task.SubProcessIngestionTask",
             configs=dict({}),
         )
 
+        test_connection_task_config = TaskConfig(
+            name="TEST_CONNECTION",
+            type="acryl.executor.execution.sub_process_test_connection_task.SubProcessTestConnectionTask",
+            configs={},
+        )
+
         if not ctx.graph:
             raise Exception(
                 "Invalid configuration provided to action. DataHub Graph Client Required. Try including the 'datahub' block in your configuration."
@@ -192,7 +198,7 @@ class ExecutorAction(Action):
         # Build default executor config
         local_executor_config = ReportingExecutorConfig(
             id=config.executor_id or "default",
-            task_configs=[local_task_config],
+            task_configs=[ingest_task_config, test_connection_task_config],
             secret_stores=[
                 SecretStoreConfig(type="env", config=dict({})),
                 SecretStoreConfig(
